pub struct SupportMove {
pub src: ProvinceAbbr,
pub dest: ProvinceAbbr,
}Expand description
A support move order. The coast of both the source and destination is not specified; only the province.
Succeeds iff
- the supporting unit is adjacent to the destination,
- the source moves to the destination, and
- the supporting unit is not tapped by a unit other than the destination.
Fields
src: ProvinceAbbrdest: ProvinceAbbrImplementations
Sourceimpl SupportMove
impl SupportMove